<?php

/**
 * @license LGPLv3, http://opensource.org/licenses/LGPL-3.0
 * @copyright Aimeos (aimeos.org), 2017-2022
 * @package MW
 * @subpackage View
 */


namespace Aimeos\Base\View\Engine;
use TYPO3\CMS\Extbase\Configuration\ConfigurationManager;


/**
 * TYPO3 view engine implementation
 *
 * @package MW
 * @subpackage View
 */
class Typo3 implements Iface
{
	private $objectManager;

	private $configuration;

	/**
	 * Initializes the view object
	 *
	 * @param \TYPO3\CMS\Extbase\Object\ObjectManagerInterface $objectManager TYPO3 object manager
	 */
	public function __construct( \TYPO3\CMS\Extbase\Object\ObjectManagerInterface $objectManager )
	{
		$this->objectManager = $objectManager;
		$this->configuration = $this->objectManager->get( ConfigurationManager::class )->getConfiguration( ConfigurationManager::CONFIGURATION_TYPE_FRAMEWORK );
	}


	/**
	 * Renders the output based on the given template file name and the key/value pairs
	 *
	 * @param \Aimeos\Base\View\Iface $view View object
	 * @param string $filename File name of the view template
	 * @param array $values Associative list of key/value pairs
	 * @return string Output generated by the template
	 * @throws \Aimeos\Base\View\Exception If the template isn't found
	 */
	public function render( \Aimeos\Base\View\Iface $view, string $filename, array $values ) : string
	{
		$fluid = $this->objectManager->get( 'TYPO3\\CMS\\Fluid\\View\\StandaloneView' );
		$fluid->setPartialRootPaths( (array) $this->configuration['view']['partialRootPaths'] );
		$fluid->setLayoutRootPaths( (array) $this->configuration['view']['layoutRootPaths'] );
		$fluid->setTemplatePathAndFilename( $filename );
		$fluid->assign( '_aimeos_view', $view );
		$fluid->assignMultiple( $values );

		return $fluid->render();
	}
}
